@@ -15,24 +15,22 @@
 #'with potentially merged leaves.}
 #'}
 #'
-#'@author Chariff Alkhassim
+#'@importFrom methods is
+#'
+#'@author Chariff Alkhassim, Boris Hejblum
 #'
 #'@export 
 RetrievePops <-function(AnnotationObj, phenotypes)
 {
-  if(class(AnnotationObj)!="Annotation")
-  {
+  if(!methods::is(AnnotationObj, "Annotation")){
     stop("AnnotationObj must be of class Annotation.")
   }
-  if(class(phenotypes)=="list")
-  {
-    if(class(phenotypes[[1]])!="matrix")
-    {
+  if(methods::is(phenotypes, "list")){
+    if(!methods::is(phenotypes[[1]], "matrix")){
       stop("Elements of phenotypes should be of class matrix.") 
     }
   }
-  else
-  {
+  else{
     stop("phenotypes should be of class list.")
   }
   labels <- AnnotationObj$labels
@@ -42,63 +40,54 @@ RetrievePops <-function(AnnotationObj, phenotypes)
   maxlab <- max(labels)
   L <- length(phenotypes)
   outlist <- list()
-  Prop <- combinations[,c("prop")]
-  for(l in 1:L)
-  {
+  Prop <- combinations[, c("prop")]
+  for(l in 1:L){
     outlist[[l]] <- list()
     temp <- phenotypes[[l]]
-    inputest <- temp[,1]%in%colnames_combinations
-    if(any(!(inputest)))
-    {
+    inputest <- temp[, 1] %in% colnames_combinations
+    if(any(!(inputest))){
       logicalinds <- as.logical(1-inputest)
-      if(sum(logicalinds) > 1)
-      {
-        wstr <- paste("markers",paste(c(temp[logicalinds,1]), 
+      if(sum(logicalinds) > 1){
+        wstr <- paste("markers",paste(c(temp[logicalinds, 1]), 
                                       collapse=", "),
                       "are not in CytomeTree.", sep = " ")
-      }
-      else
-      {
+      }else{
         wstr <- paste("marker",paste(c(temp[logicalinds,1]), 
                                       collapse=", "),
                       "is not in CytomeTree.", sep = " ")
       }
       stop(wstr)
     }
-    tempcombinations <- combinations[,temp[,1]]
-    scores <- rowSums(t(apply(tempcombinations, 1, 
-                              FUN = function(x,y)
-                              {
-                                x == y
-                              }
-                              ,y = as.numeric(temp[,2]))
-    ))
+    tempcombinations <- combinations[, temp[,1], drop=FALSE]
+    selected_pop <- apply(tempcombinations, 1, 
+                        FUN = function(x,y){ 
+                          x == y
+                        }, y = as.numeric(temp[, 2]))
+    if(is.null(dim(selected_pop))){
+      scores <- 1*selected_pop
+    }else{
+      scores <- rowSums(t(selected_pop))
+    }
     tempres <- which(scores == nrow(temp))
-    if(!length(tempres))
-    {
-      outlist[[l]][["phenotype"]] <- apply(temp[,1:2],1,paste,collapse="-") 
+    if(!length(tempres)){
+      outlist[[l]][["phenotype"]] <- apply(temp[, 1:2, drop=FALSE], 1, paste, collapse="-") 
       outlist[[l]][["proportion"]] <- NA
       outlist[[l]][["Mergedlabels"]] <- NA
       outlist[[l]][["Newlabel"]] <- NA
     }
-    else
-    {
+    else {
       leaves <- combinations[,c("leaves")][tempres]
-      outlist[[l]][["phenotype"]] <- apply(temp[,1:2],1,paste,collapse="-") 
+      outlist[[l]][["phenotype"]] <- apply(temp[,1:2, drop=FALSE],1,paste,collapse="-") 
       outlist[[l]][["proportion"]] <- sum(Prop[tempres])
-      if(length(tempres)>1)
-      {
+      if(length(tempres) > 1) {
         outlist[[l]][["Mergedlabels"]] <- leaves
         outlist[[l]][["Newlabel"]] <- maxlab + 1
         labelmerge[labels%in%leaves] <- maxlab + 1
         maxlab <- maxlab + 1
-      }
-      else
-      {
+      } else {
         outlist[[l]][["label"]] <- leaves
       }
     }
   }
   return(list("phenotypesinfo" = outlist, "Mergedleaves" = labelmerge))
 }
-
